
def mergedata(x):
    x1 = x[0]
    x2 = x[1]
    xout = zeros((len(x1)+len(x2))) 
    for ix1,ex1 in enumerate(x1):
        xout[ix1] = ex1
    for ix2,ex2 in enumerate(x2):
        xout[ix2+len(x1)] = ex2

    return xout




# generated by ./ubuntubuild.sh
from distutils.core import setup

setup(
    name='sciproc',
    version='0.6.6',
    author='H. Wouters',
    author_email='hendrikwout@gmail.com',
    packages=['sciproc'],
    url='http://www.nowebsite.com',
    license='LICENSE.txt',
    description='Process scientific multidimensional data.',
    long_description=open('README.txt').read(),
)




from datetime import datetime, timedelta

# redefine range() to make it work with datetimes
def dtrange(*args):
    if len(args) != 3:
        return range(*args)
    start, stop, step = args
    if start < stop:
        cmp = lambda a, b: a < b
        inc = lambda a: a + step
    else:
        cmp = lambda a, b: a > b
        inc = lambda a: a - step
    #output = [start]
    output = []
    while cmp(start, stop):
        output.append(start)
        start = inc(start)

    return output
